diff --git a/pgweb/core/forms.py b/pgweb/core/forms.py
index d73f3151..4a3561c0 100644
--- a/pgweb/core/forms.py
+++ b/pgweb/core/forms.py
@@ -1,6 +1,9 @@
 from django import forms
 from django.forms import ValidationError
 from django.conf import settings
+import requests
+
+from pgweb.util.url_validators import validate_urls
 
 from .models import Organisation, OrganisationEmail
 from django.contrib.auth.models import User
@@ -66,6 +69,13 @@ report, or otherwise interact with the community."""
             # remove the emails fieldset
             self.fieldsets = [fs for fs in self.fieldsets if fs['id'] != 'emails']
 
+    def clean_url(self):
+        if self.cleaned_data['url']:
+            url = self.cleaned_data['url']
+            if not validate_urls(url):
+                raise ValidationError("Please enter a working url. This url seems to be broken.")
+        return self.cleaned_data['url']
+
     def clean_add_email(self):
         if self.cleaned_data['add_email']:
             if OrganisationEmail.objects.filter(org=self.instance, address=self.cleaned_data['add_email'].lower()).exists():
diff --git a/pgweb/downloads/forms.py b/pgweb/downloads/forms.py
index 1f3d7113..0a324da3 100644
--- a/pgweb/downloads/forms.py
+++ b/pgweb/downloads/forms.py
@@ -1,6 +1,7 @@
 from django import forms
 
 from pgweb.core.models import Organisation
+from pgweb.util.url_validators import check_and_validate_markdown_urls, validate_urls
 from .models import Product
 
 
@@ -14,3 +15,18 @@ class ProductForm(forms.ModelForm):
     class Meta:
         model = Product
         exclude = ('lastconfirmed', 'approved', )
+
+    def clean_description(self):
+        if self.cleaned_data['description']:
+            content = self.cleaned_data['description']
+            if not check_and_validate_markdown_urls(content):
+                raise forms.ValidationError('Some urls present in this section seem to be broken. Kindly add valid and working urls only.')
+        return self.cleaned_data['description']
+
+    def clean_url(self):
+        if self.cleaned_data['url']:
+            url = self.cleaned_data['url']
+            if not validate_urls(url):
+                raise forms.ValidationError('The given URL seems to be broken. Kindly use a valid and working URL.')
+
+        return self.cleaned_data['url']
diff --git a/pgweb/events/forms.py b/pgweb/events/forms.py
index 59d740d4..4b1d7bd8 100644
--- a/pgweb/events/forms.py
+++ b/pgweb/events/forms.py
@@ -2,6 +2,7 @@ from django import forms
 from django.forms import ValidationError
 
 from pgweb.core.models import Organisation
+from pgweb.util.url_validators import check_and_validate_markdown_urls
 from .models import Event
 
 
@@ -26,6 +27,7 @@ class EventForm(forms.ModelForm):
 
     def clean(self):
         cleaned_data = super(EventForm, self).clean()
+        print(cleaned_data)
         if not cleaned_data.get('isonline'):
             # Non online events require city and country
             # (we don't require state, since many countries have no such thing)
@@ -35,6 +37,13 @@ class EventForm(forms.ModelForm):
             if not cleaned_data.get('country'):
                 self._errors['country'] = self.error_class(['Country must be specified for non-online events'])
                 del cleaned_data['country']
+        if cleaned_data['summary']:
+            if not check_and_validate_markdown_urls(cleaned_data['summary']):
+                self._errors['summary'] = self.error_class(['Some urls present in this section seem to be broken. Kindly add valid and working urls only.'])
+        if cleaned_data['details']:
+            if not check_and_validate_markdown_urls(cleaned_data['details']):
+                self._errors['details'] = self.error_class(['Some urls present in this section seem to be broken. Kindly add valid and working urls only.'])
+
         return cleaned_data
 
     def clean_startdate(self):
diff --git a/pgweb/news/forms.py b/pgweb/news/forms.py
index 1daa8639..9b47e1a8 100644
--- a/pgweb/news/forms.py
+++ b/pgweb/news/forms.py
@@ -3,6 +3,7 @@ from django.forms import ValidationError
 
 from pgweb.util.moderation import ModerationState
 from pgweb.core.models import Organisation, OrganisationEmail
+from pgweb.util.url_validators import check_and_validate_markdown_urls
 from .models import NewsArticle, NewsTag
 
 
@@ -33,6 +34,11 @@ class NewsArticleForm(forms.ModelForm):
     def clean(self):
         data = super().clean()
 
+        content = data['content']
+        if content:
+            if not check_and_validate_markdown_urls(content):
+                self.add_error('content', 'Some urls seem to be broken. Please use valid and working urls.')
+
         if data.get('email', None):
             if data['email'].org != data['org']:
                 self.add_error('email', 'You must pick an email address associated with the organisation')
diff --git a/pgweb/profserv/forms.py b/pgweb/profserv/forms.py
index 8427d594..5db52655 100644
--- a/pgweb/profserv/forms.py
+++ b/pgweb/profserv/forms.py
@@ -1,6 +1,7 @@
 from django import forms
 
 from pgweb.core.models import Organisation
+from pgweb.util.url_validators import validate_urls
 from .models import ProfessionalService
 
 
@@ -13,6 +14,12 @@ class ProfessionalServiceForm(forms.ModelForm):
     def filter_by_user(self, user):
         self.fields['org'].queryset = Organisation.objects.filter(managers=user, approved=True)
 
+    def clean_url(self):
+        if self.cleaned_data['url']:
+            if not validate_urls(self.cleaned_data['url']):
+                raise forms.ValidationError('The provided url seems to be broken. Kindly submit a working URL.')
+        return self.cleaned_data['url']
+
     class Meta:
         model = ProfessionalService
         exclude = ('submitter', 'approved', )
diff --git a/pgweb/util/url_validators.py b/pgweb/util/url_validators.py
new file mode 100644
index 00000000..2983ad93
--- /dev/null
+++ b/pgweb/util/url_validators.py
@@ -0,0 +1,53 @@
+
+import re
+import markdown
+import requests
+
+
+#
+# This function can be used with any markup fields to check
+# if urls present in the content are working or not.
+# It is able to detect malformed urls; For eg: htp://ky.ex
+# It will also invalidate links with empty hrefs
+# This function skips urls that refer to sections of the markdown content itself.
+# It also skips over urls that are not embedded specifically as links.
+#
+# The function parses the markdown content and extracts href values from the
+# anchor tags present in the parsed markdown.
+#
+
+
+def check_and_validate_markdown_urls(content):
+    pattern = re.compile(r'<a[\s]+([^>]+)>((?:.(?!\<\/a\>))*.)</a>')
+    content = markdown.markdown(content)
+    tag_matches = re.findall(pattern, content)
+    urls = []
+    for tag_data in tag_matches:
+        tag = tag_data[0]
+        tag = tag.replace('href=\"', "")
+        tag = tag[:tag.index('"')]
+        if not tag[0].isalpha():
+            continue
+        urls.append(tag)
+
+    for url in urls:
+        if not validate_urls(url):
+            return False
+    return True
+
+#
+# This function can be used to check if a url is valid or not.
+# It can detect malformed urls and dead urls.
+#
+
+
+def validate_urls(url):
+    broken_link_status_codes = [404, 410, 408, 504, 502, 503, 500, 403, 401, 400]
+    try:
+        res = requests.head(url, timeout=2.5)
+        if res.status_code in broken_link_status_codes:
+            return False
+    except Exception:
+        return False
+
+    return True
